.. civic-scraper documentation master file

.. include:: ../README.rst

Documentation
=============

.. toctree::

   install
   usage
   contributing
   authors
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
